Crate nargo_changes

Crate nargo_changes 

Change set management for HXO framework.

This crate provides tools for managing version changes, detecting file changes, generating changelogs, and integrating with version control systems.

Structs

ChangePreview
Change preview.
ChangeSet
Change set data structure.
ChangeSetManager
Change set manager.
ChangeSetPreset
Change set preset.
ChangeSetTemplate
Change set template.
ChangeStats
Change statistics.
ChangeTrend
Change trend analysis.
ChangeTrendPoint
Change trend data point.
FileChange
File change information.
FileChangeDetector
File change detector.
VcsIntegration
Version control system integration.

Enums

ChangeType
Change set type.
FileChangeType
File change type.
VcsType
Version control system type.